This function estimates a dynamic mixture by means of the noisy Cross-Entropy method.
Currently only implemented for the lognormal - generalized Pareto case,
with Cauchy or exponential weight. This
is mainly an auxiliary function, not suitable for the final user. Use CeNoisyFitBoot instead.
For each dataset, a list with the following elements is returned:
V (nreps x 12) matrix: updated mean and variance of the distributions used in the stochastic program.
nit (positive integer): number of iterations needed for convergence.
loglik (scalar): maximized log-likelihood.
Arguments
x
list: sequence of integers 1,...,K, where K is the mumber of datasets. Set x = 1 in case
of a single dataset.
rawdata
either a list of vectors or a vector: in the former case, each
vector contains a dataset to be used for estimation.
rho
real in (0,1): parameter determining the quantile of the log-likelihood values to be used at each iteration.
maxiter
non-negative integer: maximum number of iterations.
alpha
real in (0,1): smoothing parameter.
nsim
non-negative integer: number of replications used in the normal and lognormal updating.
nrepsInt
non-negative integer: number of replications used in the Monte Carlo estimate of the normalizing constant.
xiInst
non-negative real: shape parameter of the instrumental GPD.
betaInst
non-negative real: scale parameter of the instrumental GPD.
eps
non-negative real: tolerance for the stopping criterion of the noisy Cross-Entropy method.
r
positive integer: length of window to be used in the stopping criterion.