This function estimates a dynamic mixture by means of the noisy Cross-Entropy method and computes bootstrap standard errors. Currently only implemented for the lognormal - generalized Pareto, with Cauchy or exponential weight. Bootstrap standard errors are computed in parallel.
CENoisyFitBoot(
yObs,
nboot,
rho,
maxiter,
alpha,
nsim,
nrepsInt,
xiInst,
betaInst,
eps,
r = 5,
weight
)If nboot > 0, a list with the following elements:
estPars: Cross-Entropy estimates.
nit: number of iterations needed for convergence.
loglik: maximized log-likelihood.
bootPars: parameter estimates obtained for each bootstrap sample.
stddev: bootstrap standard errors.
If nboot = 0, only estPars, nit and loglik are returned.
numerical vector: observed random sample from the mixture.
integer: number of bootstrap replications for computing the standard errors. If nboot = 0, no standard errors are computed.
real in (0,1): parameter determining the quantile of the log-likelihood values to be used at each iteration.
non-negative integer: maximum number of iterations.
real in (0,1): smoothing parameter.
non-negative integer: number of replications used in the normal and lognormal updating.
non-negative integer: number of replications used in the Monte Carlo estimate of the normalizing constant.
non-negative real: shape parameter of the instrumental GPD.
non-negative real: scale parameter of the instrumental GPD.
non-negative real: tolerance for the stopping criterion of the noisy Cross-Entropy method.
positive integer: length of window to be used in the stopping criterion.
'cau' or 'exp': name of weight distribution.
res = CENoisyFitBoot(Metro2019,0,.05,20,.5,500,500,3,3,.01,5,'exp')
Run the code above in your browser using DataLab