Normalizing constant of the density of the lognormal-GPD mixture.
Arguments
x
if weight is equal to 'cau', (6 by 1) numerical vector: values of \(\mu_c\), \(\tau\), \(\mu\), \(\sigma\), \(\xi\), \(\beta\);
if weight is equal to 'exp', (5 by 1) numerical vector: values of \(\lambda\), \(\mu\), \(\sigma\), \(\xi\), \(\beta\).
nreps
number of replications to be used in the computation of the integral in the normalizing
constant.
xiInst
real: value of the shape parameter of the instrumental density. Default value equal to 3.
betaInst
non-negative real: value of the scale parameter of the instrumental density. Default value equal to 3.